==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/Episode.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Episode extends io.intino.sumus.graph.Event {
	protected boolean isClosed;
	protected java.util.List<io.intino.sumus.graph.Event> eventList = new java.util.ArrayList<>();

	public Episode(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public boolean isClosed() {
		return isClosed;
	}

	public Episode isClosed(boolean value) {
		this.isClosed = value;
		return (Episode) this;
	}

	public java.util.List<io.intino.sumus.graph.Event> eventList() {
		return java.util.Collections.unmodifiableList(eventList);
	}

	public io.intino.sumus.graph.Event event(int index) {
		return eventList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Event> eventList(java.util.function.Predicate<io.intino.sumus.graph.Event> predicate) {
		return eventList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(eventList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("isClosed", new java.util.ArrayList(java.util.Collections.singletonList(this.isClosed)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Event")) this.eventList.add(node.as(io.intino.sumus.graph.Event.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Event")) this.eventList.remove(node.as(io.intino.sumus.graph.Event.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("isClosed")) this.isClosed = io.intino.tara.magritte.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("isClosed")) this.isClosed = (java.lang.Boolean) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Event.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Event event(java.time.Instant created) {
		    io.intino.sumus.graph.Event newElement = core$().graph().concept(io.intino.sumus.graph.Event.class).createNode(name, core$()).as(io.intino.sumus.graph.Event.class);
			newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
		    return newElement;
		}
		public io.intino.sumus.graph.Episode episode(java.time.Instant created) {
		    io.intino.sumus.graph.Episode newElement = core$().graph().concept(io.intino.sumus.graph.Episode.class).createNode(name, core$()).as(io.intino.sumus.graph.Episode.class);
			newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
		    return newElement;
		}
	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void event(java.util.function.Predicate<io.intino.sumus.graph.Event> filter) {
			new java.util.ArrayList<>(eventList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.2.1-sources.jar: io/intino/sumus/graph/Episode.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Episode extends io.intino.sumus.graph.Event {
	protected boolean isClosed;
	protected java.util.List<io.intino.sumus.graph.Event> eventList = new java.util.ArrayList<>();

	public Episode(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public boolean isClosed() {
		return isClosed;
	}

	public Episode isClosed(boolean value) {
		this.isClosed = value;
		return (Episode) this;
	}

	public java.util.List<io.intino.sumus.graph.Event> eventList() {
		return java.util.Collections.unmodifiableList(eventList);
	}

	public io.intino.sumus.graph.Event event(int index) {
		return eventList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Event> eventList(java.util.function.Predicate<io.intino.sumus.graph.Event> predicate) {
		return eventList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(eventList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
		map.put("isClosed", new java.util.ArrayList(java.util.Collections.singletonList(this.isClosed)));
		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Event")) this.eventList.add(node.as(io.intino.sumus.graph.Event.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Event")) this.eventList.remove(node.as(io.intino.sumus.graph.Event.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
		if (name.equalsIgnoreCase("isClosed")) this.isClosed = io.intino.tara.magritte.loaders.BooleanLoader.load(values, this).get(0);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
		if (name.equalsIgnoreCase("isClosed")) this.isClosed = (java.lang.Boolean) values.get(0);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.Event.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Event event(java.time.Instant created) {
		    io.intino.sumus.graph.Event newElement = core$().graph().concept(io.intino.sumus.graph.Event.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Event.class);
			newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
		    return newElement;
		}
		public io.intino.sumus.graph.Episode episode(java.time.Instant created) {
		    io.intino.sumus.graph.Episode newElement = core$().graph().concept(io.intino.sumus.graph.Episode.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Episode.class);
			newElement.core$().set(newElement, "created", java.util.Collections.singletonList(created));
		    return newElement;
		}
	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void event(java.util.function.Predicate<io.intino.sumus.graph.Event> filter) {
			new java.util.ArrayList<>(eventList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
